<?php

namespace Drupal\search_365\Controller;

use Drupal\search_365\SearchClientInterface;
use Drupal\search_365\SearchResults\SearchQuery;
use Drupal\search_365\SearchResults\SortByLinkGenerator;

/**
 * Class SearchView.
 *
 * @package Drupal\search_365\Controller
 */
class SearchViewController {

  /**
   * Search service.
   *
   * @var \Drupal\search_365\SearchClientInterface
   */
  protected $search;

  /**
   * The page size.
   *
   * @var int
   */
  protected $pageSize;

  /**
   * The page title.
   *
   * @var string
   */
  protected $title;

  /**
   * Constructs a new SearchViewController object.
   *
   * @param \Drupal\search_365\SearchClientInterface $search
   *   Search service.
   * @param int $pageSize
   *   The page size
   * @param string $title
   *   The page title.
   */
  public function __construct(SearchClientInterface $search, $pageSize, $title) {
    $this->search = $search;
    $this->pageSize = $pageSize;
    $this->title = $title;
  }

  /**
   * Builds the search page.
   *
   * @param string $search_query
   *   The search query.
   * @param int $page
   *   The page number.
   *
   * @return array
   *   The render array.
   */
  public function get($search_query) {
    $search_query = urldecode($search_query);
    $form = drupal_get_form('search_365_search_form', $search_query);

    if ($search_query !== '') {

      // Search 365 pager starts at 1.
      $page = isset($_GET['page']) ? $_GET['page'] : 0;
      $page++;
      $sortBy = isset($_GET['sortby']) ? $_GET['sortby'] : NULL;
      $query = new SearchQuery($search_query, $page, $this->pageSize, $sortBy);
      $resultSet = $this->search->search($query);

      $sortLinks = SortByLinkGenerator::getSortByLinks($query);

      pager_default_initialize($resultSet->getResultsCount(), $this->pageSize);

      return [
        '#theme' => 'search_365_search_results',
        '#title' => $this->title,
        '#search_query' => $search_query,
        '#sort_links' => $sortLinks,
        '#results' => $resultSet,
        '#pager' => ['#type' => 'pager'],
        '#form' => $form,
      ];
    }

    return $form;
  }

}
