<?php

namespace Drupal\search_365\Form;

/**
 * Class AdministrationForm.
 *
 * @package Drupal\search_365\Form
 */
class AdministrationForm {

  /**
   * {@inheritdoc}
   */
  public static function buildForm(array $form, array &$form_state) {

    $form['connection_info'] = [
      '#title' => t('Connection Information'),
      '#type' => 'fieldset',
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    ];
    $form['connection_info']['search_365_baseurl'] = [
      '#type' => 'urlfield',
      '#title' => t('Search 365 base URL'),
      '#description' => t('Valid URL, including <em>http://</em> or <em>https://</em>. Do <b>not</b> include <em>/search</em> at the end, or a trailing slash, but you should include a port number if needed. Example: <em>http://my.example.com:8443</em>'),
      '#default_value' => variable_get('search_365_baseurl'),
      '#required' => TRUE,
    ];
    $form['connection_info']['search_365_collection'] = [
      '#type' => 'textfield',
      '#title' => t('Collection'),
      '#description' => t('The name of a valid collection (case sensitive).'),
      '#default_value' => variable_get('search_365_collection'),
      '#required' => TRUE,
    ];
    $form['display_settings'] = [
      '#title' => t('Search Interface Settings'),
      '#type' => 'fieldset',
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    ];
    $form['display_settings']['search_365_drupal_path'] = [
      '#title' => t('Search path'),
      '#type' => 'textfield',
      '#field_prefix' => '<span dir="ltr">' . url('/', [], NULL, TRUE),
      '#field_suffix' => '</span>&lrm;',
      '#default_value' => variable_get('search_365_drupal_path', 'search_365'),
      '#description' => t('The URL of the search page provided by this module. Include neither leading nor trailing slash.'),
      '#required' => TRUE,
    ];
    $form['display_settings']['search_365_search_title'] = [
      '#title' => t('Search Name'),
      '#type' => 'textfield',
      '#default_value' => variable_get('search_365_search_title'),
      '#description' => t('Serves as the page title on results pages and the default menu item title.'),
      '#required' => FALSE,
    ];
    $form['display_settings']['search_365_page_size'] = [
      '#title' => t('Page Size'),
      '#type' => 'numberfield',
      '#min' => 1,
      '#max' => 100,
      '#default_value' => variable_get('search_365_page_size'),
      '#description' => t('The number of results to return per page.'),
      '#required' => TRUE,
    ];
    return system_settings_form($form);
  }

  /**
   * {@inheritdoc}
   */
  public static function validateForm(array $form, array &$form_state) {
    if (substr($form_state['values']['search_365_baseurl'], -1) == '/') {
      form_set_error(
        'connection_info][search_365_baseurl',
        t('Base URL must not end with a slash')
      );
    }
  }

}
