<?php

namespace Drupal\search_365;

use Drupal\search_365\SearchResults\ResultSet;
use Drupal\search_365\SearchResults\SearchQuery;
use GuzzleHttp\ClientInterface;
use Symfony\Component\Serializer\SerializerInterface;

/**
 * Class SearchClient.
 *
 * @package Drupal\search_365\Service
 */
class SearchClient implements SearchClientInterface {

  /**
   * The base URL.
   *
   * @var string
   */
  protected $baseUrl;

  /**
   * The collection.
   *
   * @var string
   */
  protected $collection;

  /**
   * HTTP Client.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * The result set serializer.
   *
   * @var \Symfony\Component\Serializer\SerializerInterface
   */
  protected $serializer;

  /**
   * SearchClient constructor.
   *
   * @param $baseUrl
   *   The base URL.
   * @param $collection
   *   The collection.
   * @param \GuzzleHttp\ClientInterface $httpClient
   *   HTTP client.
   * @param \Symfony\Component\Serializer\SerializerInterface $serializer
   *   The result set serializer.
   */
  public function __construct($baseUrl, $collection, ClientInterface $httpClient, SerializerInterface $serializer) {
    $this->baseUrl = $baseUrl;
    $this->collection = $collection;
    $this->httpClient = $httpClient;
    $this->serializer = $serializer;
  }

  /**
   * {@inheritdoc}
   */
  public function search(SearchQuery $searchQuery) {
    try {
      $query = [];
      if ($sortBy = $searchQuery->getSortBy()) {
        $query['sortby'] = $sortBy;
      }
      $response = $this->httpClient->request('GET', $this->baseUrl . '/search/' . $this->collection . '/sitesearch/' . $searchQuery->getQuery() . '/' . $searchQuery->getPageNum() . '/' . $searchQuery->getSize(), [
        'query' => $query,
      ]);
      /** @var \Drupal\search_365\SearchResults\ResultSet $resultSet */
      $resultSet = $this->serializer->deserialize($response->getBody(), ResultSet::class, 'json');
      return $resultSet;
    }
    catch (\Exception $e) {
      throw new Search365Exception('Error querying search 365: ' . $e->getMessage(), $e->getCode(), $e);
    }
  }

}
