<?php

namespace Drupal\search_365\SearchResults;

/**
 * Defines a value object representing a search result.
 */
class Result {

  /**
   * Factory method for creating a new Result.
   *
   * @return self
   *   Returns static object.
   */
  public static function create() {
    return new static();
  }

  /**
   * Search title.
   *
   * @var string
   */
  protected $title;

  /**
   * Zulu time date/time.
   *
   * @var string
   */
  protected $crawlTime;

  /**
   * URL of the search result.
   *
   * @var string
   */
  protected $url;

  /**
   * Text of the result.
   *
   * @var string
   */
  protected $body;

  /**
   * Collection name.
   *
   * @var string
   */
  protected $collection;

  /**
   * System title.
   *
   * @var string
   */
  protected $systemTitle;

  /**
   * Gets the Title.
   *
   * @return string
   *   The Title.
   */
  public function getTitle() {
    return $this->title;
  }

  /**
   * Sets the Title.
   *
   * @param string $title
   *   The Title.
   *
   * @return $this
   */
  public function setTitle($title) {
    $this->title = $title;
    return $this;
  }

  /**
   * Gets the CrawlTime.
   *
   * @return string
   *   The CrawlTime.
   */
  public function getCrawlTime() {
    return $this->crawlTime;
  }

  /**
   * Sets the CrawlTime.
   *
   * @param string $crawlTime
   *   The CrawlTime.
   *
   * @return $this
   */
  public function setCrawlTime($crawlTime) {
    $this->crawlTime = $crawlTime;
    return $this;
  }

  /**
   * Gets the Url.
   *
   * @return string
   *   The Url.
   */
  public function getUrl() {
    return $this->url;
  }

  /**
   * Sets the Url.
   *
   * @param string $url
   *   The Url.
   *
   * @return $this
   */
  public function setUrl($url) {
    $this->url = $url;
    return $this;
  }

  /**
   * Gets the Body.
   *
   * @return string
   *   The Body.
   */
  public function getBody() {
    return $this->body;
  }

  /**
   * Sets the Body.
   *
   * @param string $body
   *   The Body.
   *
   * @return $this
   */
  public function setBody($body) {
    $this->body = $body;
    return $this;
  }

  /**
   * Gets the Collection.
   *
   * @return string
   *   The Collection.
   */
  public function getCollection() {
    return $this->collection;
  }

  /**
   * Sets the Collection.
   *
   * @param string $collection
   *   The Collection.
   *
   * @return $this
   */
  public function setCollection($collection) {
    $this->collection = $collection;
    return $this;
  }

  /**
   * Gets the SystemTitle.
   *
   * @return string
   *   The SystemTitle.
   */
  public function getSystemTitle() {
    return $this->systemTitle;
  }

  /**
   * Sets the SystemTitle.
   *
   * @param string $systemTitle
   *   The SystemTitle.
   *
   * @return $this
   */
  public function setSystemTitle($systemTitle) {
    $this->systemTitle = $systemTitle;
    return $this;
  }

}
