<?php
//@codingStandardsIgnoreFile
/**
 * @file
 * Contains search 365 ServiceProvider.
 */

namespace Drupal\search_365\ServiceContainer\ServiceProvider;

use Drupal\search_365\Controller\SearchViewController;
use Drupal\search_365\SearchClient;
use Drupal\search_365\Serializer\ResultSetSerializerFactory;
use Drupal\service_container\DependencyInjection\ServiceProviderInterface;
use GuzzleHttp\Client as HttpClient;

/**
 * Defines a service provider for the connector module.
 */
class Search365ServiceProvider implements ServiceProviderInterface {

  /**
   * {@inheritdoc}
   */
  public function getContainerDefinition() {
    $parameters = [
      'search_365_baseurl' => variable_get('search_365_baseurl'),
      'search_365_collection' => variable_get('search_365_collection'),
      'search_365_page_size' => variable_get('search_365_page_size'),
      'search_365_search_title' => variable_get('search_365_search_title'),
    ];

    $services = [];

    $services['search_365.search_controller'] = [
      'class' => SearchViewController::class,
      'arguments' => [
        '@search_365.search_client',
        '%search_365_page_size%',
        '%search_365_search_title%',
      ],
    ];
    $services['search_365.search_client'] = [
      'class' => SearchClient::class,
      'arguments' => [
        '%search_365_baseurl%',
        '%search_365_collection%',
        '@http_client',
        '@search_365.result_set_serializer',
      ],
    ];
    $services['http_client'] = [
      'class' => HttpClient::class,
    ];
    $services['search_365.result_set_serializer'] = [
      'factory_class' => ResultSetSerializerFactory::class,
      'factory_method' => 'create',
    ];

    return [
      'parameters' => $parameters,
      'services' => $services,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function alterContainerDefinition(&$container_definition) {}

}
